@@ -2,9 +2,15 @@
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
+
+from __future__ import annotations
+
 import logging
-import re
+from collections import namedtuple
 from copy import deepcopy
+from typing import Any, Dict, Protocol, Set
+
+import regex as re
 
 LOGGER = logging.getLogger(__name__)
 
@@ -13,6 +19,14 @@ class TemplateAttributeError(AttributeError):
     """Custom error to capture Attribute Errors in the Template"""
 
 
+class Mark(Protocol):
+    line: int
+    column: int
+
+
+_mark = namedtuple("_mark", ["line", "column"])
+
+
 def create_str_node_class(cls):
     """
     Create string node class
@@ -21,13 +35,16 @@ def create_str_node_class(cls):
     class node_class(cls):
         """Node class created based on the input class"""
 
-        def __init__(self, x, start_mark, end_mark):
+        def __init__(
+            self, x, start_mark: Mark | None = None, end_mark: Mark | None = None
+        ):
             try:
                 cls.__init__(self, x)
             except TypeError:
                 cls.__init__(self)
-            self.start_mark = start_mark
-            self.end_mark = end_mark
+
+            self.start_mark = start_mark or _mark(0, 0)
+            self.end_mark = end_mark or _mark(0, 0)
 
         # pylint: disable=bad-classmethod-argument, unused-argument
         def __new__(self, x, start_mark, end_mark):
@@ -56,13 +73,16 @@ def create_dict_node_class(cls):
     class node_class(cls):
         """Node class created based on the input class"""
 
-        def __init__(self, x, start_mark, end_mark):
+        def __init__(
+            self, x, start_mark: Mark | None = None, end_mark: Mark | None = None
+        ):
+            LOGGER.debug(type(start_mark))
             try:
                 cls.__init__(self, x)
             except TypeError:
                 cls.__init__(self)
-            self.start_mark = start_mark
-            self.end_mark = end_mark
+            self.start_mark = start_mark or _mark(0, 0)
+            self.end_mark = end_mark or _mark(0, 0)
             self.condition_functions = ["Fn::If"]
 
         def __deepcopy__(self, memo):
@@ -95,7 +115,7 @@ def create_dict_node_class(cls):
                                 if isinstance(p_v, dict):
                                     if len(p_v) == 1:
                                         for l_k in p_v.keys():
-                                            if l_k == "Fn::FindInMap":
+                                            if l_k in ["Fn::FindInMap", "Fn::GetAtt"]:
                                                 return True
 
             return False
@@ -205,12 +225,14 @@ def create_sub_node_class(cls):
     class sub_class(cls):
         """Node class created based on the input class"""
 
-        def __init__(self, x, start_mark, end_mark):
+        def __init__(
+            self, x, start_mark: Mark | None = None, end_mark: Mark | None = None
+        ):
             cls.__init__(self, x, start_mark, end_mark)
             self.__cache_is_valid = False
             self.__cache_sub_string = ""
-            self.__cache_sub_string_vars = set()
-            self.__cache_sub_vars = {}
+            self.__cache_sub_string_vars: Set[str] = set()
+            self.__cache_sub_vars: Dict[str, Any] = {}
             self.__setup()
 
         def __setup_list_sub_string(self, s):
@@ -278,13 +300,15 @@ def create_dict_list_class(cls):
     class node_class(cls):
         """Node class created based on the input class"""
 
-        def __init__(self, x, start_mark, end_mark):
+        def __init__(
+            self, x, start_mark: Mark | None = None, end_mark: Mark | None = None
+        ):
             try:
                 cls.__init__(self, x)
             except TypeError:
                 cls.__init__(self)
-            self.start_mark = start_mark
-            self.end_mark = end_mark
+            self.start_mark = start_mark or _mark(0, 0)
+            self.end_mark = end_mark or _mark(0, 0)
             self.condition_functions = ["Fn::If"]
 
         def __deepcopy__(self, memo):
