@@ -2,44 +2,44 @@
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
-from cfnlint.rules import CloudFormationLintRule
-from cfnlint.rules import RuleMatch
+
+from cfnlint.rules import CloudFormationLintRule, RuleMatch
 
 
 class AvailabilityZone(CloudFormationLintRule):
     """Check Availibility Zone parameter checks"""
 
-    id = 'W3010'
-    shortdesc = 'Availability Zone Parameters should not be hardcoded'
-    description = 'Check if an Availability Zone property is hardcoded.'
-    source_url = 'https://github.com/aws-cloudformation/cfn-python-lint'
-    tags = ['parameters', 'availabilityzone']
+    id = "W3010"
+    shortdesc = "Availability Zone Parameters should not be hardcoded"
+    description = "Check if an Availability Zone property is hardcoded."
+    source_url = "https://github.com/aws-cloudformation/cfn-python-lint"
+    tags = ["parameters", "availabilityzone"]
 
     def __init__(self):
         """Init"""
         super().__init__()
         resource_type_specs = [
-            'AWS::AutoScaling::AutoScalingGroup',
-            'AWS::DAX::Cluster',
-            'AWS::DMS::ReplicationInstance',
-            'AWS::EC2::Host',
-            'AWS::EC2::Instance',
-            'AWS::EC2::Subnet',
-            'AWS::EC2::Volume',
-            'AWS::ElasticLoadBalancing::LoadBalancer',
-            'AWS::OpsWorks::Instance',
-            'AWS::RDS::DBCluster',
-            'AWS::RDS::DBInstance',
+            "AWS::AutoScaling::AutoScalingGroup",
+            "AWS::DAX::Cluster",
+            "AWS::DMS::ReplicationInstance",
+            "AWS::EC2::Host",
+            "AWS::EC2::Instance",
+            "AWS::EC2::Subnet",
+            "AWS::EC2::Volume",
+            "AWS::ElasticLoadBalancing::LoadBalancer",
+            "AWS::OpsWorks::Instance",
+            "AWS::RDS::DBCluster",
+            "AWS::RDS::DBInstance",
         ]
 
         property_type_specs = [
             # Singular
-            'AWS::EC2::LaunchTemplate.Placement',
-            'AWS::EC2::SpotFleet.LaunchTemplateOverrides',
-            'AWS::EC2::SpotFleet.SpotPlacement',
-            'AWS::EMR::Cluster.PlacementType',
-            'AWS::ElasticLoadBalancingV2::TargetGroup.TargetDescription',
-            'AWS::Glue::Connection.PhysicalConnectionRequirements',
+            "AWS::EC2::LaunchTemplate.Placement",
+            "AWS::EC2::SpotFleet.LaunchTemplateOverrides",
+            "AWS::EC2::SpotFleet.SpotPlacement",
+            "AWS::EMR::Cluster.PlacementType",
+            "AWS::ElasticLoadBalancingV2::TargetGroup.TargetDescription",
+            "AWS::Glue::Connection.PhysicalConnectionRequirements",
         ]
 
         for resource_type_spec in resource_type_specs:
@@ -52,9 +52,9 @@ class AvailabilityZone(CloudFormationLintRule):
         matches = []
 
         # value of `all` is a valide exception in AWS::ElasticLoadBalancingV2::TargetGroup
-        if value not in ['all']:
-            if path[-1] != ['Fn::GetAZs']:
-                message = 'Don\'t hardcode {0} for AvailabilityZones'
+        if value not in ["all"]:
+            if path[-1] != ["Fn::GetAZs"]:
+                message = "Don't hardcode {0} for AvailabilityZones"
                 matches.append(RuleMatch(path, message.format(value)))
 
         return matches
@@ -66,7 +66,7 @@ class AvailabilityZone(CloudFormationLintRule):
         matches.extend(
             cfn.check_value(
                 properties,
-                'AvailabilityZone',
+                "AvailabilityZone",
                 path,
                 check_value=self.check_az_value,
                 check_ref=None,
@@ -78,7 +78,7 @@ class AvailabilityZone(CloudFormationLintRule):
         matches.extend(
             cfn.check_value(
                 properties,
-                'AvailabilityZones',
+                "AvailabilityZones",
                 path,
                 check_value=self.check_az_value,
                 check_ref=None,
