@@ -2,37 +2,38 @@
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
-import re
-from cfnlint.rules import CloudFormationLintRule
-from cfnlint.rules import RuleMatch
-from cfnlint.helpers import REGEX_DYN_REF_SSM, REGEX_DYN_REF
+
+import regex as re
+
+from cfnlint.helpers import REGEX_DYN_REF, REGEX_DYN_REF_SSM
+from cfnlint.rules import CloudFormationLintRule, RuleMatch
 
 
 class Password(CloudFormationLintRule):
     """Check if Password Properties are properly configured"""
 
-    id = 'W2501'
-    shortdesc = 'Check if Password Properties are correctly configured'
+    id = "W2501"
+    shortdesc = "Check if Password Properties are correctly configured"
     description = (
-        'Password properties should not be strings and if parameter using NoEcho'
+        "Password properties should not be strings and if parameter using NoEcho"
     )
-    source_url = 'https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/best-practices.html#creds'
-    tags = ['parameters', 'passwords', 'security', 'dynamic reference']
+    source_url = "https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/best-practices.html#creds"
+    tags = ["parameters", "passwords", "security", "dynamic reference"]
 
     def match(self, cfn):
         """Check CloudFormation Password Parameters"""
 
         matches = []
         password_properties = [
-            'AccountPassword',
-            'AdminPassword',
-            'ADDomainJoinPassword',
-            'CrossRealmTrustPrincipalPassword',
-            'KdcAdminPassword',
-            'Password',
-            'DbPassword',
-            'MasterUserPassword',
-            'PasswordParam',
+            "AccountPassword",
+            "AdminPassword",
+            "ADDomainJoinPassword",
+            "CrossRealmTrustPrincipalPassword",
+            "KdcAdminPassword",
+            "Password",
+            "DbPassword",
+            "MasterUserPassword",
+            "PasswordParam",
         ]
 
         parameters = cfn.get_parameter_names()
@@ -43,7 +44,7 @@ class Password(CloudFormationLintRule):
             trees = []
             for tree in refs:
                 if len(tree) > 2:
-                    if tree[0] == 'Resources' and tree[2] == 'Properties':
+                    if tree[0] == "Resources" and tree[2] == "Properties":
                         trees.append(tree)
 
             for tree in trees:
@@ -59,20 +60,20 @@ class Password(CloudFormationLintRule):
                 elif isinstance(obj, dict):
                     if len(obj) == 1:
                         for key, value in obj.items():
-                            if key == 'Ref':
+                            if key == "Ref":
                                 if value in parameters:
-                                    param = cfn.template['Parameters'][value]
-                                    if 'NoEcho' in param:
-                                        if not param['NoEcho']:
+                                    param = cfn.template["Parameters"][value]
+                                    if "NoEcho" in param:
+                                        if not param["NoEcho"]:
                                             fix_params.append(
                                                 {
-                                                    'Name': value,
-                                                    'Use': password_property,
+                                                    "Name": value,
+                                                    "Use": password_property,
                                                 }
                                             )
                                     else:
                                         fix_params.append(
-                                            {'Name': value, 'Use': password_property}
+                                            {"Name": value, "Use": password_property}
                                         )
                     else:
                         message = f'Inappropriate map found for password on {"/".join(map(str, tree[:-1]))}'
@@ -80,6 +81,6 @@ class Password(CloudFormationLintRule):
 
         for paramname in fix_params:
             message = f'Parameter {paramname["Name"]} used as {paramname["Use"]}, therefore NoEcho should be True'
-            tree = ['Parameters', paramname['Name']]
+            tree = ["Parameters", paramname["Name"]]
             matches.append(RuleMatch(tree, message))
         return matches
